@@ -1,13 +1,11 @@
 use swc_common::chain;
 use swc_ecma_parser::{EsConfig, Syntax};
 use swc_ecma_transforms_base::resolver::resolver;
-use swc_ecma_transforms_compat::es2015::arrow;
-use swc_ecma_transforms_compat::es2015::for_of;
-use swc_ecma_transforms_compat::es2015::function_name;
-use swc_ecma_transforms_compat::es2015::shorthand;
-use swc_ecma_transforms_module::amd::amd;
-use swc_ecma_transforms_module::amd::Config;
-use swc_ecma_transforms_module::util;
+use swc_ecma_transforms_compat::es2015::{arrow, for_of, function_name, shorthand};
+use swc_ecma_transforms_module::{
+    amd::{amd, Config},
+    util,
+};
 use swc_ecma_transforms_testing::test;
 use swc_ecma_visit::Fold;
 
